// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

'use strict';


let page = document.getElementById('buttonDiv');

const allJsonFiles = [
    {
        'name':         'Abkhaz - Abaza',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'abk',
        'file':         'matrix_turkic_sounds_cyrillic_latin_abk.json',
    },
    {
        'name':         'Adyghe',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'ady',
        'file':         'matrix_turkic_sounds_cyrillic_latin_ady.json',
    },
    {
        'name':         'Altai',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'alt',
        'file':         'matrix_turkic_sounds_cyrillic_latin_alt.json',
    },
    {
        'name':         'Avar',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'ava',
        'file':         'matrix_turkic_sounds_cyrillic_latin_ava.json',
    },
    {
        'name':         'Azerbaijani',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'aze',
        'file':         'matrix_turkic_sounds_cyrillic_latin_aze.json',
    },
    {
        'name':         'Bashkir',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'bak',
        'file':         'matrix_turkic_sounds_cyrillic_latin_bak.json',
    },
    {
        'name':         'Balkan Gagauz',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'bgx',
        'file':         'matrix_turkic_sounds_cyrillic_latin_bgx.json',
    },
    {
        'name':         'Buryat',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'bua',
        'file':         'matrix_turkic_sounds_cyrillic_latin_bua.json',
    },
    {
        'name':         'Chechen',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'che',
        'file':         'matrix_turkic_sounds_cyrillic_latin_che.json',
    },
    {
        'name':         'Mari',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'chm',
        'file':         'matrix_turkic_sounds_cyrillic_latin_chm.json',
    },
    {
        'name':         'Chuvash',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'chv',
        'file':         'matrix_turkic_sounds_cyrillic_latin_chv.json',
    },
    {
        'name':         'Chulym',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'clw',
        'file':         'matrix_turkic_sounds_cyrillic_latin_clw.json',
    },
    {
        'name':         'Crimean Tatar',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'crh',
        'file':         'matrix_turkic_sounds_cyrillic_latin_crh.json',
    },
    {
        'name':         'Dargwa',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'dar',
        'file':         'matrix_turkic_sounds_cyrillic_latin_dar.json',
    },
    {
        'name':         'Dolgan',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'dlg',
        'file':         'matrix_turkic_sounds_cyrillic_latin_dlg.json',
    },
    {
        'name':         'Fuyu Kyrgyz',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'fyk',
        'file':         'matrix_turkic_sounds_cyrillic_latin_fyk.json',
    },
    {
        'name':         'Balkan Gagauz',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'gag',
        'file':         'matrix_turkic_sounds_cyrillic_latin_gag.json',
    },
    {
        'name':         'Ingush',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'inh',
        'file':         'matrix_turkic_sounds_cyrillic_latin_inh.json',
    },
    {
        'name':         'Krymchak',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'jct',
        'file':         'matrix_turkic_sounds_cyrillic_latin_jct.json',
    },
    {
        'name':         'Karakalpak',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'kaa',
        'file':         'matrix_turkic_sounds_cyrillic_latin_kaa.json',
    },
    {
        'name':         'Kazakh',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'kaz',
        'file':         'matrix_turkic_sounds_cyrillic_latin_kaz.json',
    },
    {
        'name':         'Kabardian',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'kbd',
        'file':         'matrix_turkic_sounds_cyrillic_latin_kbd.json',
    },
    {
        'name':         'Karaim',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'kdr',
        'file':         'matrix_turkic_sounds_cyrillic_latin_kdr.json',
    },
    {
        'name':         'Tofa',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'kim',
        'file':         'matrix_turkic_sounds_cyrillic_latin_kim.json',
    },
    {
        'name':         'Kirghiz',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'kir',
        'file':         'matrix_turkic_sounds_cyrillic_latin_kir.json',
    },
    {
        'name':         'Komi',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'kom',
        'file':         'matrix_turkic_sounds_cyrillic_latin_kom.json',
    },
    {
        'name':         'Karachay-Balkar',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'krc',
        'file':         'matrix_turkic_sounds_cyrillic_latin_krc.json',
    },
    {
        'name':         'Kumyk',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'kum',
        'file':         'matrix_turkic_sounds_cyrillic_latin_kum.json',
    },
    {
        'name':         'Lezgian',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'lez',
        'file':         'matrix_turkic_sounds_cyrillic_latin_lez.json',
    },
    {
        'name':         'Mongolian',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'mon',
        'file':         'matrix_turkic_sounds_cyrillic_latin_mon.json',
    },
    {
        'name':         'Mordvinic',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'myv',
        'file':         'matrix_turkic_sounds_cyrillic_latin_myv.json',
    },
    {
        'name':         'Nogai',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'nog',
        'file':         'matrix_turkic_sounds_cyrillic_latin_nog.json',
    },
    {
        'name':         'Ossetian',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'oss',
        'file':         'matrix_turkic_sounds_cyrillic_latin_oss.json',
    },
    {
        'name':         'Russian',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'rus',
        'file':         'matrix_turkic_sounds_cyrillic_latin_rus.json',
    },
    {
        'name':         'Siberian Tatar',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'sty',
        'file':         'matrix_turkic_sounds_cyrillic_latin_sty.json',
    },
    {
        'name':         'Tatar',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'tat',
        'file':         'matrix_turkic_sounds_cyrillic_latin_tat.json',
    },
    {
        'name':         'Turkmen',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'tuk',
        'file':         'matrix_turkic_sounds_cyrillic_latin_tuk.json',
    },
    {
        'name':         'Tuvan',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'tyv',
        'file':         'matrix_turkic_sounds_cyrillic_latin_tyv.json',
    },
    {
        'name':         'Udmurt',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'udm',
        'file':         'matrix_turkic_sounds_cyrillic_latin_udm.json',
    },
    {
        'name':         'Uyghur (arabic)',
        'type_from':    'arabic',
        'type_to':      'latin',
        'iso639_3':     'uig',
        'file':         'matrix_turkic_sounds_arabic_latin_uig.json',
    },
    {
        'name':         'Uighur (cyrillic)',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'uig',
        'file':         'matrix_turkic_sounds_cyrillic_latin_uig.json',
    },
    {
        'name':         'Urum',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'uum',
        'file':         'matrix_turkic_sounds_cyrillic_latin_uum.json',
    },
    {
        'name':         'Uzbek',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'uzb',
        'file':         'matrix_turkic_sounds_cyrillic_latin_uzb.json',
    },
    {
        'name':         'Kalmyk Oirat',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'xal',
        'file':         'matrix_turkic_sounds_cyrillic_latin_xal.json',
    },
    {
        'name':         'Yakut',
        'type_from':    'cyrillic',
        'type_to':      'latin',
        'iso639_3':     'sah',
        'file':         'matrix_turkic_sounds_cyrillic_latin_sah.json',
    }
];









const kButtonColors = ['tat', 'kaz'];
function constructOptions(kButtonColors) {

    //Create and append select list
    var selectList = document.createElement("select");
    selectList.id = "mySelect";
    page.appendChild(selectList);

    for (var i = 0; i < allJsonFiles.length; i++) {
        var option = document.createElement("option");
        option.value = i;
        option.text = allJsonFiles[i].name;
        option.setAttribute('id', i);
        option.setAttribute('data-type_from', allJsonFiles[i].type_from);
        option.setAttribute('data-type_to', allJsonFiles[i].type_to);
        selectList.appendChild(option);
    }

    selectList.addEventListener("change", (event) => {

      document.getElementById('type-from').textContent = 'from ' + allJsonFiles[event.target.value].type_from;
      document.getElementById('type-to').textContent = 'to ' + allJsonFiles[event.target.value].type_to;

        chrome.storage.sync.set({
            language: {
                type_from: allJsonFiles[event.target.value].type_from,
                type_to: allJsonFiles[event.target.value].type_to,
                iso639_3: allJsonFiles[event.target.value].iso639_3
            }
        }, function() {
            console.log('iso639_3 is ' + event.target.value);
        })

    });

}
constructOptions(kButtonColors);
